# Cloudbeds Fiscal Document
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `cloudbeds_fiscal_document` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.12.0
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with Cloudbeds Fiscal Document,
you can run the following:

```python

import cloudbeds_fiscal_document
from cloudbeds_fiscal_document.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:8700
# See configuration.py for a list of all supported configuration parameters.
configuration = cloudbeds_fiscal_document.Configuration(
    host = "http://localhost:8700"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): bearerAuth
configuration = cloudbeds_fiscal_document.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with cloudbeds_fiscal_document.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = cloudbeds_fiscal_document.ConfigsApi(api_client)
    x_property_id = 56 # int | Property id

    try:
        # Delete logo image for fiscal documents
        api_instance.delete_logo(x_property_id)
    except ApiException as e:
        print("Exception when calling ConfigsApi->delete_logo: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:8700*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ConfigsApi* | [**delete_logo**](cloudbeds_fiscal_document/docs/ConfigsApi.md#delete_logo) | **DELETE** /fiscal-document/v1/configs/logo | Delete logo image for fiscal documents
*ConfigsApi* | [**get_configs**](cloudbeds_fiscal_document/docs/ConfigsApi.md#get_configs) | **GET** /fiscal-document/v1/configs | Get list of fiscal documents configs
*ConfigsApi* | [**get_logo**](cloudbeds_fiscal_document/docs/ConfigsApi.md#get_logo) | **GET** /fiscal-document/v1/configs/logo | Get logo image for fiscal documents
*ConfigsApi* | [**get_pdf_preview**](cloudbeds_fiscal_document/docs/ConfigsApi.md#get_pdf_preview) | **GET** /fiscal-document/v1/configs/preview | Get PDF document preview
*ConfigsApi* | [**update_configs**](cloudbeds_fiscal_document/docs/ConfigsApi.md#update_configs) | **PUT** /fiscal-document/v1/configs/{documentKind} | Updates a config of a specific kind
*ConfigsApi* | [**upload_logo**](cloudbeds_fiscal_document/docs/ConfigsApi.md#upload_logo) | **POST** /fiscal-document/v1/configs/logo | Upload logo image for fiscal documents
*FeaturesApi* | [**get_property_features**](cloudbeds_fiscal_document/docs/FeaturesApi.md#get_property_features) | **GET** /fiscal-document/v1/property/features | Get enabled features for the current user and property
*FiscalDocumentsApi* | [**allocate_receipt_payment**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#allocate_receipt_payment) | **POST** /fiscal-document/v1/fiscal-documents/receipt/allocate-payment | Allocate payment associated with receipt to charge transactions.
*FiscalDocumentsApi* | [**create_credit_note**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#create_credit_note) | **POST** /fiscal-document/v1/fiscal-documents/credit-note | Create a fiscal document of the type credit note
*FiscalDocumentsApi* | [**create_invoice**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#create_invoice) | **POST** /fiscal-document/v1/fiscal-documents/invoice | Create a fiscal document of the type invoice
*FiscalDocumentsApi* | [**create_pro_forma_invoice**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#create_pro_forma_invoice) | **POST** /fiscal-document/v1/fiscal-documents/pro-forma-invoice | Create a fiscal document of the type pro forma invoice
*FiscalDocumentsApi* | [**create_receipt**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#create_receipt) | **POST** /fiscal-document/v1/fiscal-documents/receipt | Create receipt for a payment.
*FiscalDocumentsApi* | [**create_rectify_invoice**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#create_rectify_invoice) | **POST** /fiscal-document/v1/fiscal-documents/rectify-invoice | Create a fiscal document of the type rectify invoice
*FiscalDocumentsApi* | [**create_simple_receipt**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#create_simple_receipt) | **POST** /fiscal-document/v1/fiscal-documents/simple-receipt | Create simple receipts.
*FiscalDocumentsApi* | [**download_fiscal_document**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#download_fiscal_document) | **GET** /fiscal-document/v1/fiscal-documents/{id}/download | Download fiscal document
*FiscalDocumentsApi* | [**email_fiscal_document**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#email_fiscal_document) | **POST** /fiscal-document/v1/fiscal-documents/{id}/email | Email a fiscal document
*FiscalDocumentsApi* | [**get_allocations**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_allocations) | **GET** /fiscal-document/v1/fiscal-documents/allocations | Get payment allocation transactions
*FiscalDocumentsApi* | [**get_allocations_summary**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_allocations_summary) | **GET** /fiscal-document/v1/fiscal-documents/allocations/summary | Get allocations summary
*FiscalDocumentsApi* | [**get_credit_note_preview**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_credit_note_preview) | **POST** /fiscal-document/v1/fiscal-documents/credit-note/preview | Get fiscal document preview of the type credit note
*FiscalDocumentsApi* | [**get_document_preview**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_document_preview) | **POST** /fiscal-document/v1/fiscal-documents/invoice/preview | Get fiscal document preview of the type invoice
*FiscalDocumentsApi* | [**get_fiscal_document_recipients_by_id**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_fiscal_document_recipients_by_id) | **GET** /fiscal-document/v1/fiscal-documents/{id}/recipients | Get list of recipients associated to the fiscal document
*FiscalDocumentsApi* | [**get_fiscal_document_transactions**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_fiscal_document_transactions) | **GET** /fiscal-document/v1/fiscal-documents/transactions | Get available transactions for fiscal documents
*FiscalDocumentsApi* | [**get_fiscal_document_transactions_by_id**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_fiscal_document_transactions_by_id) | **GET** /fiscal-document/v1/fiscal-documents/{id}/transactions | Get list of transactions for a given fiscal document id
*FiscalDocumentsApi* | [**get_fiscal_document_transactions_for_allocation**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_fiscal_document_transactions_for_allocation) | **GET** /fiscal-document/v1/fiscal-documents/allocations/transactions | Get available transactions for allocations
*FiscalDocumentsApi* | [**get_fiscal_documents**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_fiscal_documents) | **GET** /fiscal-document/v1/fiscal-documents | Get list of fiscal documents
*FiscalDocumentsApi* | [**get_pro_forma_preview**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_pro_forma_preview) | **POST** /fiscal-document/v1/fiscal-documents/pro-forma-invoice/preview | Create a fiscal document of the type pro forma invoice
*FiscalDocumentsApi* | [**get_rectify_invoice_preview**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_rectify_invoice_preview) | **POST** /fiscal-document/v1/fiscal-documents/rectify-invoice/preview | Get fiscal document preview of the type rectify invoice
*FiscalDocumentsApi* | [**get_selected_transactions_summary**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_selected_transactions_summary) | **GET** /fiscal-document/v1/fiscal-documents/transactions/summary | Get totals of selected available transactions for fiscal documents
*FiscalDocumentsApi* | [**get_transactions_summary_by_document_id**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#get_transactions_summary_by_document_id) | **GET** /fiscal-document/v1/fiscal-documents/{id}/transactions/summary | Get totals of transactions for a given fiscal document id
*FiscalDocumentsApi* | [**put_fiscal_document**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#put_fiscal_document) | **PUT** /fiscal-document/v1/fiscal-documents/{id} | Update a fiscal document by id
*FiscalDocumentsApi* | [**update_pro_forma_invoice_status**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#update_pro_forma_invoice_status) | **PUT** /fiscal-document/v1/fiscal-documents/pro-forma-invoice/{id}/status | Update pro forma invoice status
*FiscalDocumentsApi* | [**void_receipt**](cloudbeds_fiscal_document/docs/FiscalDocumentsApi.md#void_receipt) | **POST** /fiscal-document/v1/fiscal-documents/receipts/{receiptId}/void | Void a receipt


## Documentation For Models

 - [Action](cloudbeds_fiscal_document/docs/Action.md)
 - [AllocateReceiptPaymentRequest](cloudbeds_fiscal_document/docs/AllocateReceiptPaymentRequest.md)
 - [AllocationsData](cloudbeds_fiscal_document/docs/AllocationsData.md)
 - [AllocationsSummary](cloudbeds_fiscal_document/docs/AllocationsSummary.md)
 - [ApiError](cloudbeds_fiscal_document/docs/ApiError.md)
 - [ConfigsResponse](cloudbeds_fiscal_document/docs/ConfigsResponse.md)
 - [ConfigsUpdateRequest](cloudbeds_fiscal_document/docs/ConfigsUpdateRequest.md)
 - [CreateCreditNoteRequest](cloudbeds_fiscal_document/docs/CreateCreditNoteRequest.md)
 - [CreateInvoiceRequest](cloudbeds_fiscal_document/docs/CreateInvoiceRequest.md)
 - [CreateReceiptRequest](cloudbeds_fiscal_document/docs/CreateReceiptRequest.md)
 - [CreateSimpleReceiptRequest](cloudbeds_fiscal_document/docs/CreateSimpleReceiptRequest.md)
 - [CreationMethod](cloudbeds_fiscal_document/docs/CreationMethod.md)
 - [DocumentAction](cloudbeds_fiscal_document/docs/DocumentAction.md)
 - [DocumentTriggerEvent](cloudbeds_fiscal_document/docs/DocumentTriggerEvent.md)
 - [FiscalDocumentDetailedResponse](cloudbeds_fiscal_document/docs/FiscalDocumentDetailedResponse.md)
 - [FiscalDocumentEmailRequest](cloudbeds_fiscal_document/docs/FiscalDocumentEmailRequest.md)
 - [FiscalDocumentFilters](cloudbeds_fiscal_document/docs/FiscalDocumentFilters.md)
 - [FiscalDocumentKind](cloudbeds_fiscal_document/docs/FiscalDocumentKind.md)
 - [FiscalDocumentPaginated](cloudbeds_fiscal_document/docs/FiscalDocumentPaginated.md)
 - [FiscalDocumentPatchRequest](cloudbeds_fiscal_document/docs/FiscalDocumentPatchRequest.md)
 - [FiscalDocumentRecipient](cloudbeds_fiscal_document/docs/FiscalDocumentRecipient.md)
 - [FiscalDocumentStatus](cloudbeds_fiscal_document/docs/FiscalDocumentStatus.md)
 - [FiscalDocumentSummaryResponse](cloudbeds_fiscal_document/docs/FiscalDocumentSummaryResponse.md)
 - [FiscalDocumentTransactionAllocation](cloudbeds_fiscal_document/docs/FiscalDocumentTransactionAllocation.md)
 - [FiscalDocumentTransactionResponse](cloudbeds_fiscal_document/docs/FiscalDocumentTransactionResponse.md)
 - [FiscalDocumentTransactionsForAllocationPaginated](cloudbeds_fiscal_document/docs/FiscalDocumentTransactionsForAllocationPaginated.md)
 - [FiscalDocumentTransactionsPaginated](cloudbeds_fiscal_document/docs/FiscalDocumentTransactionsPaginated.md)
 - [FiscalDocumentTransactionsSummary](cloudbeds_fiscal_document/docs/FiscalDocumentTransactionsSummary.md)
 - [FiscalDocumentTransactionsSummaryTaxesInner](cloudbeds_fiscal_document/docs/FiscalDocumentTransactionsSummaryTaxesInner.md)
 - [GetCreditNotePreviewRequest](cloudbeds_fiscal_document/docs/GetCreditNotePreviewRequest.md)
 - [GetInvoicePreviewRequest](cloudbeds_fiscal_document/docs/GetInvoicePreviewRequest.md)
 - [GetLogoResponse](cloudbeds_fiscal_document/docs/GetLogoResponse.md)
 - [GetRectifyInvoiceNotePreviewRequest](cloudbeds_fiscal_document/docs/GetRectifyInvoiceNotePreviewRequest.md)
 - [GovernmentIntegration](cloudbeds_fiscal_document/docs/GovernmentIntegration.md)
 - [GovernmentIntegrationQr](cloudbeds_fiscal_document/docs/GovernmentIntegrationQr.md)
 - [LatestLinkedDocument](cloudbeds_fiscal_document/docs/LatestLinkedDocument.md)
 - [LinkedDocument](cloudbeds_fiscal_document/docs/LinkedDocument.md)
 - [PreviewRequest](cloudbeds_fiscal_document/docs/PreviewRequest.md)
 - [ProFormaInvoicePreviewRequest](cloudbeds_fiscal_document/docs/ProFormaInvoicePreviewRequest.md)
 - [ProFormaInvoiceRequest](cloudbeds_fiscal_document/docs/ProFormaInvoiceRequest.md)
 - [ProFormaStatusUpdateRequest](cloudbeds_fiscal_document/docs/ProFormaStatusUpdateRequest.md)
 - [PropertyConfigsResponse](cloudbeds_fiscal_document/docs/PropertyConfigsResponse.md)
 - [ReceiptTransactionAllocation](cloudbeds_fiscal_document/docs/ReceiptTransactionAllocation.md)
 - [RecipientAddress](cloudbeds_fiscal_document/docs/RecipientAddress.md)
 - [RecipientCompany](cloudbeds_fiscal_document/docs/RecipientCompany.md)
 - [RecipientContactDetails](cloudbeds_fiscal_document/docs/RecipientContactDetails.md)
 - [RecipientDetails](cloudbeds_fiscal_document/docs/RecipientDetails.md)
 - [RecipientDocument](cloudbeds_fiscal_document/docs/RecipientDocument.md)
 - [RecipientRequest](cloudbeds_fiscal_document/docs/RecipientRequest.md)
 - [RecipientTaxInfo](cloudbeds_fiscal_document/docs/RecipientTaxInfo.md)
 - [RecipientType](cloudbeds_fiscal_document/docs/RecipientType.md)
 - [RectifyInvoiceNoteRequest](cloudbeds_fiscal_document/docs/RectifyInvoiceNoteRequest.md)
 - [SingleAllocation](cloudbeds_fiscal_document/docs/SingleAllocation.md)
 - [SourceKind](cloudbeds_fiscal_document/docs/SourceKind.md)
 - [TransactionForAllocationResponse](cloudbeds_fiscal_document/docs/TransactionForAllocationResponse.md)
 - [TransactionStatus](cloudbeds_fiscal_document/docs/TransactionStatus.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (JWT)


## Author




